@@ -27,7 +27,7 @@
 /*                                                                          */
 /****************************************************************************/
 
-#include "config.h"
+#include <config.h>
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
