@@ -45,10 +45,10 @@
 #ifndef __DDDI_H__
 #define __DDDI_H__
 
-#include <limits.h>
+#include <climits>
 
 
-#include <assert.h>
+#include <cassert>
 
 #include "ugtypes.h"
 #include "architecture.h"
@@ -63,13 +63,6 @@
 
 START_UGDIM_NAMESPACE
 
-/****************************************************************************/
-
-/*
-        macro in order to turn usage of register variables on/off
- */
-#define REGISTER register
-
 /*
         macro for exiting program in case of a severe error condition
  */
@@ -80,9 +73,9 @@ START_UGDIM_NAMESPACE
 /*
         macros for correct return or premature abort of a procedure
  */
-#define RET_ON_OK      return (TRUE)
-#define RET_ON_ERROR   return (FALSE)
-#define IS_OK(p)       ((p)==TRUE)
+#define RET_ON_OK      return (true)
+#define RET_ON_ERROR   return (false)
+#define IS_OK(p)       ((p)==true)
 typedef int RETCODE;
 
 
@@ -282,7 +275,7 @@ typedef struct _TYPE_DESC
   //int    nextFree;				/* next free object in arrays           */
   int elemHeader;                       /* which rec. type-elem contains hdr?
                                            (offsetHeader gives local offset)    */
-                                        /* (hasHeader must be TRUE)             */
+                                        /* (hasHeader must be true)             */
 #endif
 
   /* if C_FRONTEND or (CPP_FRONTEND and storage==STORAGE_STRUCT) */
@@ -383,16 +376,9 @@ extern VChannelPtr *theTopology;
 
 #define YES     1
 #define ON      1
-#ifndef TRUE
-#define TRUE    1
-#endif
 
 #define NO      0
 #define OFF     0
-#ifndef FALSE
-#define FALSE   0
-#endif
-
 
 
 
