@@ -106,7 +106,7 @@ enum HandlerSets
 
 /* macros for ddd object info */
 /* for elements */
-#define EPRIO(e)                                                DDD_InfoPriority(PARHDRE(e))
+#define EPRIO(e)                                                (Priorities)DDD_InfoPriority(PARHDRE(e))
 #define SETEPRIO(e,p)                                   DDD_PrioritySet(PARHDRE(e),p)
 #define SETEPRIOX(e,p)                                  if (EPRIO(e)!=p) DDD_PrioritySet(PARHDRE(e),p)
 #define EMASTER(e)                                              (EPRIO(e) == PrioMaster)
@@ -315,7 +315,6 @@ void    IdentifyInit                                    (MULTIGRID *theMG);
 void    IdentifyExit                                    (void);
 INT             Identify_Objects_of_ElementSide (GRID *theGrid, ELEMENT *theElement, INT i);
 INT             Identify_SonNodesAndSonEdges    (GRID *theGrid);
-INT             IdentifyGridLevels                              (MULTIGRID *theMG, INT FromLevel, INT ToLevel);
 
 /* from overlap.c */
 
